@@ -28,12 +28,6 @@ class TracksListenerTests: public QObject, public DatabaseTestData
 {
     Q_OBJECT
 
-public:
-
-    TracksListenerTests(QObject *parent = nullptr) : QObject(parent)
-    {
-    }
-
 private Q_SLOTS:
 
     void initTestCase()
@@ -81,7 +75,7 @@ private Q_SLOTS:
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
         QCOMPARE(tracksListAddedSpy.count(), 0);
 
-        myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
+        myDatabaseContent.insertTracksList(mNewTracks);
 
         QCOMPARE(trackHasChangedSpy.count(), 0);
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
@@ -215,7 +209,7 @@ private Q_SLOTS:
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
         QCOMPARE(tracksListAddedSpy.count(), 0);
 
-        myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
+        myDatabaseContent.insertTracksList(mNewTracks);
 
         QCOMPARE(trackHasChangedSpy.count(), 0);
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
@@ -283,7 +277,7 @@ private Q_SLOTS:
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
         QCOMPARE(tracksListAddedSpy.count(), 0);
 
-        myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
+        myDatabaseContent.insertTracksList(mNewTracks);
 
         QCOMPARE(trackHasChangedSpy.count(), 0);
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
@@ -362,7 +356,7 @@ private Q_SLOTS:
         QCOMPARE(myPlayList.data(myPlayList.index(0, 0), MediaPlayList::ColumnsRoles::TrackNumberRole).toInt(), -1);
         QCOMPARE(myPlayList.data(myPlayList.index(0, 0), MediaPlayList::ColumnsRoles::DiscNumberRole).toInt(), 0);
 
-        myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
+        myDatabaseContent.insertTracksList(mNewTracks);
 
         QCOMPARE(trackHasChangedSpy.count(), 1);
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
@@ -416,7 +410,7 @@ private Q_SLOTS:
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
         QCOMPARE(tracksListAddedSpy.count(), 0);
 
-        myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
+        myDatabaseContent.insertTracksList(mNewTracks);
 
         QCOMPARE(trackHasChangedSpy.count(), 0);
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
@@ -446,7 +440,7 @@ private Q_SLOTS:
                                                 QDateTime::fromMSecsSinceEpoch(1),
                                                 {QUrl::fromLocalFile(QStringLiteral("file://image$1"))}, 1, false,
                                                 {}, {}, QStringLiteral("lyricist1"), false}
-                                           }, mNewCovers);
+                                           });
 
         QCOMPARE(trackHasChangedSpy.count(), 2);
         QCOMPARE(trackHasBeenRemovedSpy.count(), 0);
