@@ -70,7 +70,7 @@ private Q_SLOTS:
         QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews);
         QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
@@ -144,10 +144,10 @@ private Q_SLOTS:
         QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews);
         QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews - 1);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
-        QCOMPARE(beginInsertRowsSpy.count(), 4);
-        QCOMPARE(endInsertRowsSpy.count(), 4);
+        QCOMPARE(beginInsertRowsSpy.count(), 1);
+        QCOMPARE(endInsertRowsSpy.count(), 1);
         QCOMPARE(beginRemoveRowsSpy.count(), 0);
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
@@ -174,15 +174,10 @@ private Q_SLOTS:
                 QUrl::fromLocalFile(QStringLiteral("album3")), 5, true,
                 QStringLiteral("genre5"), QStringLiteral("composer1"), QStringLiteral("lyricist1"), false}};
 
-        auto newCovers = mNewCovers;
-        newCovers[QStringLiteral("/test/$23")] = QUrl::fromLocalFile(QStringLiteral("album3"));
-        newCovers[QStringLiteral("/test/$24")] = QUrl::fromLocalFile(QStringLiteral("album3"));
-        newCovers[QStringLiteral("/test/$25")] = QUrl::fromLocalFile(QStringLiteral("album3"));
+        musicDb.insertTracksList(newTracks);
 
-        musicDb.insertTracksList(newTracks, newCovers);
-
-        QCOMPARE(beginInsertRowsSpy.count(), 7);
-        QCOMPARE(endInsertRowsSpy.count(), 7);
+        QCOMPARE(beginInsertRowsSpy.count(), 2);
+        QCOMPARE(endInsertRowsSpy.count(), 2);
         QCOMPARE(beginRemoveRowsSpy.count(), 0);
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
@@ -197,17 +192,15 @@ private Q_SLOTS:
             QUrl::fromLocalFile(QStringLiteral("album3")), 5, true,
             QStringLiteral("a genre"), QStringLiteral("composer1"), QStringLiteral("lyricist1"), false};
 
-        const auto newCover = QHash<QString, QUrl>{{QStringLiteral("/test/$26"), QUrl::fromLocalFile(QStringLiteral("album3"))}};
+        musicDb.insertTracksList({newTrack});
 
-        musicDb.insertTracksList({newTrack}, newCover);
-
-        QCOMPARE(beginInsertRowsSpy.count(), 8);
-        QCOMPARE(endInsertRowsSpy.count(), 8);
-        QCOMPARE(beginRemoveRowsSpy.count(), 0);
-        QCOMPARE(endRemoveRowsSpy.count(), 0);
+        QCOMPARE(beginInsertRowsSpy.count(), 3);
+        QCOMPARE(endInsertRowsSpy.count(), 3);
+        QCOMPARE(beginRemoveRowsSpy.count(), 1);
+        QCOMPARE(endRemoveRowsSpy.count(), 1);
         QCOMPARE(dataChangedSpy.count(), 0);
-        QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews + 8);
-        QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews - 1 + 8);
+        QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews + 7);
+        QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews - 1 + 7);
 
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(0, 0), Qt::DisplayRole), QStringLiteral("Now Playing"));
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(1, 0), Qt::DisplayRole), QStringLiteral("Recently Played"));
@@ -224,15 +217,14 @@ private Q_SLOTS:
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(12, 0), Qt::DisplayRole), QStringLiteral("genre4"));
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(13, 0), Qt::DisplayRole), QStringLiteral("genre5"));
         QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(14, 0), Qt::DisplayRole), QStringLiteral("genre6"));
-        QCOMPARE(viewsProxyModel.data(viewsProxyModel.index(15, 0), Qt::DisplayRole), QStringLiteral("genre7"));
 
         viewsModel.viewsData()->setEmbeddedCategory(ElisaUtils::Unknown);
         viewsProxyModel.setEmbeddedCategory(ElisaUtils::Unknown);
 
-        QCOMPARE(beginInsertRowsSpy.count(), 8);
-        QCOMPARE(endInsertRowsSpy.count(), 8);
-        QCOMPARE(beginRemoveRowsSpy.count(),1);
-        QCOMPARE(endRemoveRowsSpy.count(), 1);
+        QCOMPARE(beginInsertRowsSpy.count(), 3);
+        QCOMPARE(endInsertRowsSpy.count(), 3);
+        QCOMPARE(beginRemoveRowsSpy.count(), 2);
+        QCOMPARE(endRemoveRowsSpy.count(), 2);
         QCOMPARE(dataChangedSpy.count(), 0);
         QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews);
         QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews);
@@ -279,7 +271,7 @@ private Q_SLOTS:
         QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews);
         QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews - 1);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -309,12 +301,7 @@ private Q_SLOTS:
                 QUrl::fromLocalFile(QStringLiteral("album10")), 5, true,
                 QStringLiteral("genre5"), QStringLiteral("composer1"), QStringLiteral("lyricist1"), false}};
 
-        auto newCovers = mNewCovers;
-        newCovers[QStringLiteral("/test/$23")] = QUrl::fromLocalFile(QStringLiteral("album8"));
-        newCovers[QStringLiteral("/test/$24")] = QUrl::fromLocalFile(QStringLiteral("album9"));
-        newCovers[QStringLiteral("/test/$25")] = QUrl::fromLocalFile(QStringLiteral("album10"));
-
-        musicDb.insertTracksList(newTracks, newCovers);
+        musicDb.insertTracksList(newTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 2);
         QCOMPARE(endInsertRowsSpy.count(), 2);
@@ -669,7 +656,7 @@ private Q_SLOTS:
         QCOMPARE(viewsModel.rowCount(), mNumOfBaseViews);
         QCOMPARE(viewsProxyModel.rowCount(), mNumOfBaseViews);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
