@@ -18,12 +18,6 @@
 #include <KFileMetaData/UserMetaData>
 #include <KFileMetaData/Properties>
 
-#if KFBaloo_FOUND
-
-#include <Baloo/File>
-
-#endif
-
 #endif
 
 #include <QFileInfo>
@@ -32,17 +26,24 @@
 #include <QHash>
 #include <QMimeDatabase>
 
+QStringList buildCoverFileNames(const QStringList &fileNames, const QStringList &fileExtensions)
+{
+    QStringList covers {};
+    for (const auto &fileName : fileNames) {
+        for (const auto &fileExtension : fileExtensions) {
+            covers.push_back(fileName + fileExtension);
+        }
+    }
+    return covers;
+}
+
 class FileScannerPrivate
 {
 public:
 #if KFFileMetaData_FOUND
     KFileMetaData::ExtractorCollection mAllExtractors;
 
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     KFileMetaData::PropertyMultiMap mAllProperties;
-#else
-    KFileMetaData::PropertyMap mAllProperties;
-#endif
 
     KFileMetaData::EmbeddedImageData mImageScanner;
 #endif
@@ -75,6 +76,7 @@ public:
         QStringLiteral(".jpg")
         ,QStringLiteral(".jpeg")
         ,QStringLiteral(".png")
+        ,QStringLiteral(".webp")
     };
 
     const QStringList constCoverNames {
@@ -91,27 +93,13 @@ public:
         ,QStringLiteral("*[Aa]lbumart*")
     };
 
-    QStringList coverFileAllImages;
-    QStringList coverFileNames;
-    QStringList coverFileGlobs;
+    const QStringList coverFileAllImages = buildCoverFileNames({QStringLiteral("*")}, constCoverExtensions);
+    const QStringList coverFileNames = buildCoverFileNames(constCoverNames, constCoverExtensions);
+    const QStringList coverFileGlobs = buildCoverFileNames(constCoverGlobs, constCoverExtensions);
 };
 
-QStringList buildCoverFileNames(const QStringList &fileNames, const QStringList &fileExtensions)
-{
-    QStringList covers {};
-    for (auto fileName : fileNames) {
-        for (auto fileExtension : fileExtensions) {
-            covers.push_back(fileName + fileExtension);
-        }
-    }
-    return covers;
-}
-
 FileScanner::FileScanner() : d(std::make_unique<FileScannerPrivate>())
 {
-    d->coverFileAllImages = buildCoverFileNames({QStringLiteral("*")}, d->constCoverExtensions);
-    d->coverFileNames = buildCoverFileNames(d->constCoverNames, d->constCoverExtensions);
-    d->coverFileGlobs = buildCoverFileNames(d->constCoverGlobs, d->constCoverExtensions);
 }
 
 bool FileScanner::shouldScanFile(const QString &scanFile)
@@ -130,14 +118,14 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile, const QF
         return newTrack;
     }
 
-    const auto &localFileName = scanFile.toLocalFile();
-
     newTrack[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
     newTrack[DataTypes::ResourceRole] = scanFile;
     newTrack[DataTypes::RatingRole] = 0;
     newTrack[DataTypes::ElementTypeRole] = ElisaUtils::Track;
 
 #if KFFileMetaData_FOUND
+    const auto &localFileName = scanFile.toLocalFile();
+
     const auto &fileMimeType = d->mMimeDb.mimeTypeForFile(localFileName);
     if (!fileMimeType.name().startsWith(QLatin1String("audio/"))) {
         return newTrack;
@@ -193,34 +181,6 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
     }
 }
 
-DataTypes::TrackDataType FileScanner::scanOneBalooFile(const QUrl &scanFile, const QFileInfo &scanFileInfo)
-{
-    DataTypes::TrackDataType newTrack;
-#if KFBaloo_FOUND
-    const auto &localFileName = scanFile.toLocalFile();
-
-    newTrack[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
-    newTrack[DataTypes::ResourceRole] = scanFile;
-    newTrack[DataTypes::RatingRole] = 0;
-    newTrack[DataTypes::ElementTypeRole] = ElisaUtils::Track;
-
-    Baloo::File match(localFileName);
-
-    match.load();
-
-    d->mAllProperties = match.properties();
-    scanProperties(match.path(), newTrack);
-
-    qCDebug(orgKdeElisaIndexer()) << "scanOneFile" << scanFile << "using Baloo" << newTrack;
-#else
-    Q_UNUSED(scanFile)
-    Q_UNUSED(scanFileInfo)
-
-    qCDebug(orgKdeElisaIndexer()) << "scanOneFile" << scanFile << "no baloo metadata provider" << newTrack;
-#endif
-    return newTrack;
-}
-
 void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackDataType &trackData)
 {
 #if KFFileMetaData_FOUND
@@ -266,6 +226,7 @@ void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackD
         trackData[DataTypes::ImageUrlRole] = QUrl(QLatin1String("image://cover/") + localFileName);
     } else {
         trackData[DataTypes::HasEmbeddedCover] = false;
+        trackData[DataTypes::ImageUrlRole] = searchForCoverFile(localFileName);
     }
 
 #if !defined Q_OS_ANDROID && !defined Q_OS_WIN
@@ -301,6 +262,11 @@ QUrl FileScanner::searchForCoverFile(const QString &localFileName)
     trackFileDir.setNameFilters(d->coverFileAllImages);
     QFileInfoList coverFiles = trackFileDir.entryInfoList();
 
+    if (coverFiles.isEmpty()) {
+        directoryCache.insert(trackFileDir.path(), QUrl());
+        return QUrl();
+    }
+
     if (coverFiles.length() != 1) {
         trackFileDir.setNameFilters(d->coverFileNames);
         coverFiles = trackFileDir.entryInfoList();
@@ -339,7 +305,7 @@ bool FileScanner::checkEmbeddedCoverImage(const QString &localFileName)
 {
 #if KFFileMetaData_FOUND
     const auto &mimeType = QMimeDatabase().mimeTypeForFile(localFileName).name();
-    auto extractors = d->mAllExtractors.fetchExtractors(mimeType);
+    const auto extractors = d->mAllExtractors.fetchExtractors(mimeType);
 
     for (const auto &extractor : extractors) {
         KFileMetaData::SimpleExtractionResult result(localFileName, mimeType, KFileMetaData::ExtractionResult::ExtractImageData);
