@@ -8,24 +8,23 @@
 #define MANAGEAUDIOPLAYER_H
 
 #include "elisaLib_export.h"
+#include "elisautils.h"
 
 #include <QObject>
 #include <QPersistentModelIndex>
+#include <QQmlEngine>
 #include <QAbstractItemModel>
 #include <QUrl>
 #include <QMediaPlayer>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#define PlaybackState State
-#define playbackState state
-#endif
-
 class QDateTime;
 
 class ELISALIB_EXPORT ManageAudioPlayer : public QObject
 {
     Q_OBJECT
 
+    QML_ELEMENT
+
     Q_PROPERTY(QPersistentModelIndex currentTrack
                READ currentTrack
                WRITE setCurrentTrack
@@ -167,7 +166,9 @@ Q_SIGNALS:
 
     void playerStop();
 
-    void skipNextTrack();
+    void skipNextTrack(ElisaUtils::SkipReason reason = ElisaUtils::SkipReason::Automatic);
+
+    void skipPreviousTrack(qint64 position);
 
     void audioDurationChanged();
 
@@ -197,6 +198,8 @@ Q_SIGNALS:
 
     void startedPlayingTrack(const QUrl &fileName, const QDateTime &time);
 
+    void finishedPlayingTrack(const QUrl &fileName, const QDateTime &time);
+
     void updateData(const QPersistentModelIndex &index, const QVariant &value, int role);
 
 public Q_SLOTS:
@@ -222,6 +225,8 @@ public Q_SLOTS:
     void ensurePause();
 
     void ensurePlay();
+    
+    void requestPlay();
 
     void playPause();
 
@@ -243,7 +248,7 @@ public Q_SLOTS:
 
     void playListFinished();
 
-    void tracksDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles);
+    void tracksDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QList<int> &roles);
 
     void setTitleRole(int titleRole);
 
@@ -261,7 +266,7 @@ private:
 
     void triggerStop();
 
-    void triggerSkipNextTrack();
+    void triggerSkipNextTrack(ElisaUtils::SkipReason reason = ElisaUtils::SkipReason::Automatic);
 
     void restorePreviousState();
 
