@@ -16,7 +16,6 @@
 #include "managemediaplayercontrol.h"
 #include "manageheaderbar.h"
 #include "audiowrapper.h"
-#include <kfilemetadata/extractorcollection.h>
 
 #if KFFileMetaData_FOUND
 #include <KFileMetaData/ExtractorCollection>
@@ -68,8 +67,8 @@ MediaPlayer2Player::MediaPlayer2Player(MediaPlayListProxyModel *playListControle
             this, &MediaPlayer2Player::audioDurationChanged);
     connect(m_audioPlayer, &AudioWrapper::volumeChanged,
             this, &MediaPlayer2Player::playerVolumeChanged);
-    connect(m_playListControler, &MediaPlayListProxyModel::shufflePlayListChanged,
-            this, &MediaPlayer2Player::shufflePlayListChanged);
+    connect(m_playListControler, &MediaPlayListProxyModel::shuffleModeChanged,
+            this, &MediaPlayer2Player::shuffleModeChanged);
     connect(m_playListControler, &MediaPlayListProxyModel::repeatModeChanged,
             this, &MediaPlayer2Player::repeatModeChanged);
 
@@ -129,7 +128,7 @@ void MediaPlayer2Player::Next()
     Q_EMIT next();
 
     if (m_playListControler) {
-        m_playListControler->skipNextTrack();
+        m_playListControler->skipNextTrack(ElisaUtils::SkipReason::Manual);
     }
 }
 
@@ -428,7 +427,7 @@ QVariantMap MediaPlayer2Player::getMetadataOfCurrentTrack()
 
             const auto &mimeType = QMimeDatabase().mimeTypeForFile(m_manageHeaderBar->image().toString().mid(14)).name();
             KFileMetaData::ExtractorCollection extractorCollection;
-            auto extractors = extractorCollection.fetchExtractors(mimeType);
+            const auto extractors = extractorCollection.fetchExtractors(mimeType);
 
             QMap<KFileMetaData::EmbeddedImageData::ImageType, QByteArray> imageData;
             for (const auto &extractor : extractors) {
@@ -500,7 +499,8 @@ void MediaPlayer2Player::setMediaPlayerPresent(int status)
 void MediaPlayer2Player::setShuffle(bool shuffle)
 {
     if (m_playListControler) {
-        m_playListControler->setShufflePlayList(shuffle);
+        MediaPlayListProxyModel::Shuffle shuffleMode = shuffle ? MediaPlayListProxyModel::Shuffle::Track : MediaPlayListProxyModel::Shuffle::NoShuffle;
+        m_playListControler->setShuffleMode(shuffleMode);
         signalPropertiesChange(QStringLiteral("Shuffle"), Shuffle());
     }
 }
@@ -508,13 +508,13 @@ void MediaPlayer2Player::setShuffle(bool shuffle)
 bool MediaPlayer2Player::Shuffle() const
 {
     if (m_playListControler) {
-        return m_playListControler->shufflePlayList();
+        return (m_playListControler->shuffleMode() != MediaPlayListProxyModel::Shuffle::NoShuffle);
     }
 
     return false;
 }
 
-void MediaPlayer2Player::shufflePlayListChanged()
+void MediaPlayer2Player::shuffleModeChanged()
 {
     signalPropertiesChange(QStringLiteral("Shuffle"), Shuffle());
 }
