@@ -18,15 +18,9 @@
 #include <UpnpServiceDescription>
 #include <UpnpActionDescription>
 
-#include <QDomDocument>
-#include <QDomElement>
-#include <QDomNode>
 
 #include <QHash>
 #include <QString>
-#include <QList>
-#include <QLoggingCategory>
-#include <QPointer>
 #include <QUrl>
 
 class UpnpContentDirectoryModelPrivate
@@ -49,7 +43,7 @@ public:
 
     QHash<QString, quintptr> mUpnpIds;
 
-    QHash<quintptr, QVector<quintptr> > mChilds;
+    QHash<quintptr, QList<quintptr> > mChilds;
 
     QHash<quintptr, DataTypes::UpnpTrackDataType> mAllTrackData;
 
@@ -193,9 +187,9 @@ QVariant UpnpContentDirectoryModel::data(const QModelIndex &index, int role) con
                 result = d->mAllTrackData[index.internalId()][DataTypes::ImageUrlRole].toUrl();
             } else {
                 if (d->mUseLocalIcons) {
-                    result = QUrl(QStringLiteral("qrc:/media-optical-audio.svg"));
+                    result = QUrl(QStringLiteral("qrc:/media-default-album.svg"));
                 } else {
-                    result = QUrl(QStringLiteral("image://icon/media-optical-audio"));
+                    result = QUrl(QStringLiteral("image://icon/media-default-album"));
                 }
             }
             break;
@@ -564,7 +558,7 @@ void UpnpContentDirectoryModel::setParentId(QString parentId)
 
     d->mUpnpIds[d->mParentId] = d->mLastInternalId;
 
-    d->mChilds[d->mLastInternalId] = QVector<quintptr>();
+    d->mChilds[d->mLastInternalId] = QList<quintptr>();
 
     d->mAllTrackData[d->mLastInternalId] = {{DataTypes::IdRole, d->mParentId},
                                             {DataTypes::ElementTypeRole, QVariant::fromValue(ElisaUtils::Container)},
